pub struct MethodMessenger<T: Hasher> { /* private fields */ }Expand description
Utility to invoke standard methods on deployed actors.
Implementations
Sourceimpl<T: Hasher> MethodMessenger<T>
impl<T: Hasher> MethodMessenger<T>
Sourcepub fn new(hasher: T) -> Self
pub fn new(hasher: T) -> Self
Creates a new method messenger using a specified hashing function (blake2b by default).
Sourcepub fn call_method(
&self,
to: &Address,
method: &str,
params: Option<IpldBlock>,
value: TokenAmount,
) -> Result<Response, MethodMessengerError>
pub fn call_method( &self, to: &Address, method: &str, params: Option<IpldBlock>, value: TokenAmount, ) -> Result<Response, MethodMessengerError>
Calls a method (by name) on a specified actor by constructing and publishing the underlying on-chain message.